@@ -1,20 +1,20 @@
-/* stringprep.c	library implementing IETF stringprep specification
+/* stringprep.c		Core stringprep implementation.
  * Copyright (C) 2002  Simon Josefsson
  *
- * This file is part of libstringprep.
+ * This file is part of GNU Libidn.
  *
- * Libstringprep is free software; you can redistribute it and/or
+ * GNU Libidn is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * Libstringprep is distributed in the hope that it will be useful,
+ * GNU Libidn is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with libstringprep; if not, write to the Free Software
+ * License along with GNU Libidn; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
@@ -105,6 +105,16 @@ stringprep_apply_table_to_string (unsigned long *ucs4,
  * as stringprep_nameprep(), stringprep_kerberos5() etc instead of
  * calling this function directly.
  *
+ * Since the stringprep operation can expand the string, @maxlen
+ * indicate how large the buffer holding the string is.  The @flags
+ * are one of Stringprep_profile_flags, or 0.  The profile indicates
+ * processing details, see the profile header files, such as
+ * stringprep_generic.h and stringprep_nameprep.h for two examples.
+ * Your application can define new profiles, possibly re-using the
+ * generic stringprep tables that always will be part of the library.
+ * Note that you must convert strings entered in the systems locale
+ * into UTF-8 before using this function.
+ *
  * Return value: Returns 0 iff successful, or an error code.
  **/
 int
@@ -119,7 +129,7 @@ stringprep (char *in, int maxlen, int flags, Stringprep_profile * profile)
   int maxucs4len;
 
   ucs4 = stringprep_utf8_to_ucs4 (in, -1, &ucs4len);
-  maxucs4len = 4 * ucs4len + 10;
+  maxucs4len = 4 * ucs4len + 10; /* XXX */
   ucs4 = realloc (ucs4, 1 + maxucs4len * sizeof (unsigned long));
   if (!ucs4)
     {
